@@ -25,7 +25,7 @@ class App extends Component<{}> {
     return (
       <View style={styles.container}>
         <Text style={styles.welcome}>
-          Welcome to Electrode Native BeNoIt!
+          Welcome to BeNoIt!
         </Text>
         <Text style={styles.instructions}>
           Wanna get started ? Edit App.js
